@@ -118,6 +118,8 @@ def update_nodes(item, appwrapper_name, min_cpu, max_cpu, min_memory, max_memory
             update_affinity(spec, appwrapper_name, instascale)
             update_image(spec, image)
             update_env(spec, env)
+            if comp == head:
+                gpu = 0
             update_resources(spec, min_cpu, max_cpu, min_memory, max_memory, gpu)
 
 def write_user_appwrapper(user_yaml, output_file_name):
